{*
 *******************************************************************************
 *
 *  Copyright 2020 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.48';
  RDB_META_DATA_ITEMS_DATE = '2021-04-16';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["angle","range_mean","amplitude_mean"],"description":"Ang'
      + 'ular notch filter parameters for window glass echoes","type":"object",'
      + '"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ran'
      + 'ge_mean":{"type":"array","description":"Mean range [m]","items":{"type'
      + '":"number"}},"angle":{"type":"array","description":"Angle [deg]","item'
      + 's":{"type":"number"}},"amplitude_mean":{"type":"array","description":"'
      + 'Mean amplitude [dB]","items":{"type":"number"}}},"title":"Angular '
      + 'Notch Filter"}'
    );

    Example : (''
      + '{"range_mean":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0'
      + '.068,0.0675,0.06475],"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,'
      + '22.0,23.0,24.0],"amplitude_mean":[3.780913,3.780913,3.480913,3.120913,'
      + '2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}'
    );
  );

// Atmospheric Parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric Parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["temperature","pressure","rel_humidity","pressure_sl","am'
      + 'sl","group_velocity","attenuation","wavelength"],"description":"Atmosp'
      + 'heric Parameters","type":"object","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","properties":{"rel_humidity":{"type":"number","descrip'
      + 'tion":"Relative humidity along measurement path '
      + '[%]"},"pressure_sl":{"type":"number","description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]"},"group_velocity":{"type":"number","description":"Group '
      + 'velocity of laser beam '
      + '[m/s]"},"amsl":{"type":"number","description":"Height above mean sea '
      + 'level (AMSL) [m]"},"pressure":{"type":"number","description":"Pressure'
      + ' along measurment path '
      + '[mbar]"},"wavelength":{"type":"number","description":"Laser wavelength'
      + ' [nm]"},"attenuation":{"type":"number","description":"Atmospheric '
      + 'attenuation '
      + '[1/km]"},"temperature":{"type":"number","description":"Temperature '
      + 'along measurement path [\u00b0C]"}},"title":"Atmospheric Parameters"}'
    );

    Example : (''
      + '{"rel_humidity":63,"pressure_sl":970,"group_velocity":299711000.0,"ams'
      + 'l":0,"pressure":970,"wavelength":1550,"attenuation":0.028125,"temperat'
      + 'ure":7}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["beam_exit_diameter","beam_divergence"],"description":"La'
      + 'ser beam geometry details","type":"object","$schema":"http://json-sche'
      + 'ma.org/draft-04/schema#","properties":{"beam_exit_diameter":{"type":"n'
      + 'umber","minimum":0,"exclusiveMinimum":false,"description":"Beam width '
      + 'at exit aperture [m]"},"beam_divergence":{"type":"number","minimum":0,'
      + '"exclusiveMinimum":false,"description":"Beam divergence in far field '
      + '[rad]"}},"title":"Beam Geometry"}'
    );

    Example : (''
      + '{"beam_exit_diameter":0.0072,"beam_divergence":0.0003}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["types"],"description":"List of control object type defin'
      + 'itions","type":"object","$schema":"http://json-schema.org/draft-04/sch'
      + 'ema#","properties":{"types":{"type":"array","items":{"type":"object","'
      + 'oneOf":[{"$ref":"#/definitions/rectangle"},{"$ref":"#/definitions/chec'
      + 'kerboard2x2"},{"$ref":"#/definitions/chevron"},{"$ref":"#/definitions/'
      + 'circular_disk"},{"$ref":"#/definitions/cylinder"},{"$ref":"#/definitio'
      + 'ns/sphere"},{"$ref":"#/definitions/round_corner_cube_prism"}]},"unique'
      + 'Items":true}},"definitions":{"common":{"type":"object","required":["na'
      + 'me","shape"],"properties":{"name":{"type":"string","description":"uniq'
      + 'ue type identifier","minLength":3},"shape":{"type":"string","enum":["r'
      + 'ectangle","checkerboard2x2","chevron","circular_disk","cylinder","sphe'
      + 're","round_corner_cube_prism"],"description":"shape '
      + 'identifier"},"description":{"type":"string","description":"string '
      + 'describing the object"},"surface_type":{"type":"string","enum":["retro'
      + '_reflective_foil","diffuse"],"description":"surface material '
      + 'type"}},"description":"common object properties"},"rectangle":{"type":'
      + '"object","allOf":[{"$ref":"#/definitions/common"},{"type":"object","re'
      + 'quired":["shape","length","width"],"properties":{"length":{"type":"num'
      + 'ber","minimum":0,"exclusiveMinimum":true,"description":"length in mete'
      + 'rs"},"shape":{"type":"string","enum":["rectangle"]},"width":{"type":"n'
      + 'umber","minimum":0,"exclusiveMinimum":true,"description":"width in '
      + 'meters"}},"description":"rectangle specific properties"}],"description'
      + '":"rectangle"},"sphere":{"type":"object","allOf":[{"$ref":"#/definitio'
      + 'ns/common"},{"type":"object","required":["shape","diameter"],"properti'
      + 'es":{"shape":{"type":"string","enum":["sphere"],"description":"shape i'
      + 'dentifier"},"diameter":{"type":"number","minimum":0,"exclusiveMinimum"'
      + ':true,"description":"diameter in meters"}},"description":"sphere '
      + 'specific properties"}],"description":"sphere"},"round_corner_cube_pris'
      + 'm":{"type":"object","allOf":[{"$ref":"#/definitions/common"},{"type":"'
      + 'object","required":["shape","diameter"],"properties":{"offset":{"type"'
      + ':"number","description":"offset in meters, e.g. reflector constant (op'
      + 'tional)"},"shape":{"type":"string","enum":["round_corner_cube_prism"],'
      + '"description":"shape identifier"},"diameter":{"type":"number","minimum'
      + '":0,"exclusiveMinimum":true,"description":"diameter in '
      + 'meters"}},"description":"round corner cube prism specific '
      + 'properties"}],"description":"round corner cube prism"},"checkerboard2x'
      + '2":{"type":"object","allOf":[{"$ref":"#/definitions/common"},{"type":"'
      + 'object","required":["shape","square_length"],"properties":{"square_len'
      + 'gth":{"type":"number","minimum":0,"exclusiveMinimum":true,"description'
      + '":"length of a square of the checkerboard in meters"},"shape":{"type":'
      + '"string","enum":["checkerboard2x2"],"description":"shape '
      + 'identifier"}},"description":"checkerboard specific '
      + 'properties"}],"description":"checkerboard 2 by 2"},"circular_disk":{"t'
      + 'ype":"object","allOf":[{"$ref":"#/definitions/common"},{"type":"object'
      + '","required":["shape","diameter"],"properties":{"offset":{"type":"numb'
      + 'er","description":"offset in meters, e.g. reflector constant (optional'
      + ')"},"shape":{"type":"string","enum":["circular_disk"],"description":"s'
      + 'hape identifier"},"diameter":{"type":"number","minimum":0,"exclusiveMi'
      + 'nimum":true,"description":"diameter in '
      + 'meters"}},"description":"circular disk specific '
      + 'properties"}],"description":"circular disk"},"chevron":{"type":"object'
      + '","allOf":[{"$ref":"#/definitions/common"},{"type":"object","required"'
      + ':["shape","outside_edge_length","thickness"],"properties":{"outside_ed'
      + 'ge_length":{"type":"number","minimum":0,"exclusiveMinimum":true,"descr'
      + 'iption":"length of the two outer edges in meters"},"thickness":{"type"'
      + ':"number","minimum":0,"exclusiveMinimum":true,"description":"thickness'
      + ' in meters"},"shape":{"type":"string","enum":["chevron"],"description"'
      + ':"shape identifier"}},"description":"chevron specific properties"}],"d'
      + 'escription":"chevron"},"cylinder":{"type":"object","allOf":[{"$ref":"#'
      + '/definitions/common"},{"type":"object","required":["shape","diameter",'
      + '"height"],"properties":{"height":{"type":"number","minimum":0,"exclusi'
      + 'veMinimum":true,"description":"height in meters"},"shape":{"type":"str'
      + 'ing","enum":["cylinder"],"description":"shape identifier"},"diameter":'
      + '{"type":"number","minimum":0,"exclusiveMinimum":true,"description":"di'
      + 'ameter in meters"}},"description":"cylinder specific '
      + 'properties"}],"description":"cylinder"}},"title":"Control Object '
      + 'Catalog"}'
    );

    Example : (''
      + '{"types":[{"name":"Rectangle 60x30","length":0.6,"width":0.3,"shape":"'
      + 'rectangle","description":"Rectangle (60cm x 30cm)"},{"name":"Rectangle'
      + ' 80x40","length":0.8,"width":0.4,"shape":"rectangle","description":"Re'
      + 'ctangle (80cm x 40cm)"},{"name":"Checkerboard2x2 30","square_length":0'
      + '.3,"shape":"checkerboard2x2","description":"Checkerboard (square '
      + 'length: 30cm)"},{"name":"Checkerboard2x2 50","square_length":0.5,"shap'
      + 'e":"checkerboard2x2","description":"Checkerboard (square length: '
      + '50cm)"},{"name":"Chevron 24''''/4''''","outside_edge_length":0.6096,"thick'
      + 'ness":0.1016,"shape":"chevron","description":"Chevron (a=24''''; '
      + 'b=4'''')"},{"name":"Circular Disk '
      + '50","surface_type":"diffuse","shape":"circular_disk","description":" '
      + 'Circular Disk (diameter: 50cm)","diameter":0.5},{"name":"RIEGL flat '
      + 'reflector 50 '
      + 'mm","surface_type":"retro_reflective_foil","description":"flat '
      + 'circular reflector from retro-reflective foil","offset":0.0,"shape":"c'
      + 'ircular_disk","diameter":0.05},{"name":"RIEGL flat reflector 100 '
      + 'mm","surface_type":"retro_reflective_foil","description":"flat '
      + 'circular reflector from retro-reflective foil","offset":0.0,"shape":"c'
      + 'ircular_disk","diameter":0.1},{"name":"RIEGL flat reflector 150 '
      + 'mm","surface_type":"retro_reflective_foil","description":"flat '
      + 'circular reflector from retro-reflective foil","offset":0.0,"shape":"c'
      + 'ircular_disk","diameter":0.15},{"name":"RIEGL cylindrical reflector 50'
      + ' mm","surface_type":"retro_reflective_foil","description":"cylindrical'
      + ' reflector from retro-reflective '
      + 'foil","shape":"cylinder","height":0.05,"diameter":0.05},{"name":"RIEGL'
      + ' cylindrical reflector 100 '
      + 'mm","surface_type":"retro_reflective_foil","description":"cylindrical '
      + 'reflector from retro-reflective '
      + 'foil","shape":"cylinder","height":0.1,"diameter":0.1},{"name":"Sphere '
      + '200 mm","shape":"sphere","description":"Sphere (diameter: 200 '
      + 'mm)","diameter":0.2},{"name":"Corner Cube Prism 50 mm","offset":0.0,"s'
      + 'hape":"round_corner_cube_prism","description":"round corner cube '
      + 'prism","diameter":0.05}],"comments":["This file contains a list of '
      + 'control object types (aka. ''catalog'').","Each type is described by an '
      + 'object,","which must contain at least the following parameters:","  - '
      + 'name: unique identifier of the type","  - shape: one of the following '
      + 'supported shapes:","      - rectangle","      - checkerboard2x2","'
      + '      - chevron","      - circular_disk","      - cylinder","      - '
      + 'sphere","      - round_corner_cube_prism","Depending on ''shape'', the '
      + 'following parameters must/may be specified:","  - rectangle:","      -'
      + ' length: length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height:  height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or ''diffuse'')"]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"reference_file":{"type":"object","required":["file_uuid"'
      + ',"file_path"],"properties":{"file_uuid":{"type":"string","description"'
      + ':"Control object file''s Universally Unique Identifier (RFC '
      + '4122)"},"file_path":{"type":"string","description":"Path of the '
      + 'control object file relative to referring '
      + 'file"}},"description":"Reference to a control object '
      + 'file"}},"description":"Details about the control object reference '
      + 'file","title":"Control Object Reference file"}'
    );

    Example : (''
      + '{"reference_file":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213",'
      + '"file_path":"../../../10_CONTROL_OBJECTS/ControlPoints.cpx"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["amplitude","detection_probability"],"description":"Detec'
      + 'tion probability as a function of amplitude","type":"object","$schema"'
      + ':"http://json-schema.org/draft-04/schema#","properties":{"amplitude":{'
      + '"type":"array","description":"Amplitude [dB]","items":{"type":"number"'
      + '}},"detection_probability":{"type":"array","description":"Detection '
      + 'probability [0..1]","items":{"type":"number"}}},"title":"Detection '
      + 'Probability"}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"detection'
      + '_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["device_type","serial_number"],"description":"Details '
      + 'about the device used to acquire the point cloud","type":"object","$sc'
      + 'hema":"http://json-schema.org/draft-04/schema#","properties":{"device_'
      + 'build":{"type":"string","description":"Device build '
      + 'variant"},"device_type":{"type":"string","description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)"},"device_name":{"type":"string","description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)"},"serial_number":{"type":"string","description":"Device '
      + 'serial number (e.g. '
      + 'S2221234)"},"channel_text":{"type":"string","description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel devices)"}'
      + ',"channel_number":{"type":"integer","minimum":0,"exclusiveMinimum":fal'
      + 'se,"description":"Laser channel number (not defined or 0: single '
      + 'channel device)"}},"title":"Device Information"}'
    );

    Example : (''
      + '{"device_build":"","device_type":"VZ-400i","device_name":"Scanner '
      + '1","serial_number":"S2221234","channel_text":"","channel_number":0}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["primary"],"description":"Scanner device geometry details'
      + '","type":"object","$schema":"http://json-schema.org/draft-04/schema#",'
      + '"properties":{"amu":{"type":"object","properties":{"lineCC":{"type":"n'
      + 'umber","minimum":0,"exclusiveMinimum":false,"description":"Line Circle'
      + ' Count (number of LSBs per full rotation about line axis)"},"frameCC":'
      + '{"type":"number","minimum":0,"exclusiveMinimum":false,"description":"F'
      + 'rame Circle Count (number of LSBs per full rotation about frame '
      + 'axis)"}},"description":"Angle Measurement Unit"},"primary":{"type":"ob'
      + 'ject","required":["ID","content"],"properties":{"ID":{"type":"array","'
      + 'minItems":2,"maxItems":2,"description":"Structure identifier","items":'
      + '{"type":"integer"}},"content":{"type":"array","description":"Internal '
      + 'calibration values","items":{"type":"number"}}},"description":"Primary'
      + ' device geometry structure (mandatory)"},"secondary":{"type":"object",'
      + '"required":["ID","content"],"properties":{"ID":{"type":"array","minIte'
      + 'ms":2,"maxItems":2,"description":"Structure identifier","items":{"type'
      + '":"integer"}},"content":{"type":"array","description":"Internal '
      + 'calibration '
      + 'values","items":{"type":"number"}}},"description":"Additional device '
      + 'geometry structure (optional)"}},"title":"Device Geometry"}'
    );

    Example : (''
      + '{"amu":{"lineCC":124000,"frameCC":124000},"primary":{"ID":[4,0],"conte'
      + 'nt":[0]},"secondary":{"ID":[91,0],"content":[0]}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["primary"],"description":"Scanner passive channel device '
      + 'geometry details","type":"object","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","properties":{"primary":{"type":"object","required":["'
      + 'ID","content"],"properties":{"ID":{"type":"array","minItems":2,"maxIte'
      + 'ms":2,"description":"Structure identifier","items":{"type":"integer"}}'
      + ',"content":{"type":"array","description":"Internal calibration '
      + 'values","items":{"type":"number"}}},"description":"Primary device '
      + 'geometry structure (mandatory)"}},"title":"Device Geometry Passive '
      + 'Channel"}'
    );

    Example : (''
      + '{"primary":{"ID":[143,0],"content":[0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"amplitude_maximum":{"type":"number","description":"Maxim'
      + 'um possible amplitude in '
      + 'dB."},"deviation_maximum":{"type":"number","description":"Maximum '
      + 'possible pulse shape deviation."},"background_radiation_minimum":{"typ'
      + 'e":"number","description":"Minimum possible background '
      + 'radiation."},"range_minimum":{"type":"number","description":"Minimum '
      + 'possible range in meters."},"reflectance_maximum":{"type":"number","de'
      + 'scription":"Maximum possible reflectance in '
      + 'dB."},"deviation_minimum":{"type":"number","description":"Minimum '
      + 'possible pulse shape deviation."},"mta_zone_count_maximum":{"type":"nu'
      + 'mber","description":"Maximum number of MTA '
      + 'zones."},"reflectance_minimum":{"type":"number","description":"Minimum'
      + ' possible reflectance in '
      + 'dB."},"range_maximum":{"type":"number","description":"Maximum possible'
      + ' range in '
      + 'meters."},"amplitude_minimum":{"type":"number","description":"Minimum '
      + 'possible amplitude in '
      + 'dB."},"echo_count_maximum":{"type":"number","description":"Maximum '
      + 'number of echoes a laser shot can have."},"background_radiation_maximu'
      + 'm":{"type":"number","description":"Maximum possible background '
      + 'radiation."}},"description":"Limits of the measured values output by '
      + 'the device. The limits depend on the device type, measurement program '
      + 'and/or scan pattern.","title":"Device Output Limits"}'
    );

    Example : (''
      + '{"amplitude_maximum":100.0,"background_radiation_maximum":0,"deviation'
      + '_maximum":32767,"background_radiation_minimum":0,"range_maximum":10000'
      + '.0,"amplitude_minimum":0.0,"range_minimum":2.9,"reflectance_maximum":1'
      + '00.0,"deviation_minimum":-1,"mta_zone_count_maximum":7,"reflectance_mi'
      + 'nimum":-100.0}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["echo_file"],"description":"Details about echo files","ty'
      + 'pe":"object","$schema":"http://json-schema.org/draft-04/schema#","prop'
      + 'erties":{"echo_file":{"type":"object","required":["file_extension"],"p'
      + 'roperties":{"file_extension":{"type":"string","description":"Echo file'
      + ' extension, without the leading '
      + 'dot"},"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)"}}}},"title":"Echo Information"}'
    );

    Example : (''
      + '{"echo_file":{"file_extension":"owp","file_uuid":"26a03615-67c0-4bea-8'
      + 'fe8-c577378fe661"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"additionalProperties":false,"description":"Details for exponential '
      + 'decomposition of full waveform data","type":"object","$schema":"http:/'
      + '/json-schema.org/draft-04/schema#","patternProperties":{"^[0-9]+$":{"d'
      + 'escription":"one field per channel, field name is channel index","$ref'
      + '":"#/definitions/channel"}},"definitions":{"channel":{"type":"object",'
      + '"required":["delay","scale","parameter"],"properties":{"delay":{"type"'
      + ':"number","description":"delay calibration in seconds"},"parameter":{"'
      + 'type":"object","required":["A","B","gamma","omega"],"properties":{"gam'
      + 'ma":{"type":"array","description":"decay in 1/second","items":{"type":'
      + '"number"}},"omega":{"type":"array","description":"angular frequency in'
      + ' '
      + 'Hz","items":{"type":"number"}},"A":{"type":"array","description":"real'
      + ' part of amplitude factor in units of full-scale","items":{"type":"num'
      + 'ber"}},"B":{"type":"array","description":"imaginary part of amplitude '
      + 'factor in units of '
      + 'full-scale","items":{"type":"number"}}},"description":"parameters of '
      + 'the syswave exponential sum"},"a_lin":{"minimum":0,"exclusiveMinimum":'
      + 'false,"description":"relative linear amplitude range [0..1]","type":"n'
      + 'umber","maximum":1,"exclusiveMaximum":false},"scale":{"type":"number",'
      + '"description":"amplitude calibration"}}}},"title":"Exponential '
      + 'Decomposition"}'
    );

    Example : (''
      + '{"0":{"delay":3.783458418887631e-09,"parameter":{"gamma":[-1094726528.'
      + '0,-769562752.0,-848000064.0],"omega":[352020896.0,3647927552.0,-197798'
      + '7072.0],"A":[0.9772450923919678,0.3354335129261017,-1.312678575515747]'
      + ',"B":[-3.9813032150268555,0.08622030913829803,-0.3152860999107361]},"a'
      + '_lin":0.27,"scale":1.0},"1":{"delay":3.5e-09,"parameter":{"gamma":[-10'
      + '94726528.0,-769562752.0,-848000064.0],"omega":[352020896.0,3647927552.'
      + '0,-1977987072.0],"A":[0.9,0.3,-1.3],"B":[-3.9,0.0,-0.3]},"a_lin":0.9,"'
      + 'scale":1.0}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["amplitude_lsb_low_power","amplitude_lsb_high_power","amp'
      + 'litude_db","range_offset_sec_low_power","range_offset_sec_high_power"]'
      + ',"description":"riegl.gaussian_decomposition contains information '
      + 'relevant for extracting calibrated amplitudes and calibrated ranges '
      + 'from a Gaussian decomposition of full waveform data. This information '
      + 'is contained in a table with five columns. Two columns are to be used '
      + 'as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The '
      + 'other three columns provide the outputs. Amplitude_db gives the '
      + 'calibrated amplitude in the optical regime in decibels. The range '
      + 'offset columns provide additive range offsets, given in units of '
      + 'seconds, for each channel.","type":"object","$schema":"http://json-sch'
      + 'ema.org/draft-04/schema#","properties":{"amplitude_lsb_high_power":{"t'
      + 'ype":"array","items":{"type":"number"}},"range_offset_sec_high_power":'
      + '{"type":"array","items":{"type":"number"}},"amplitude_lsb_low_power":{'
      + '"type":"array","items":{"type":"number"}},"range_offset_sec_low_power"'
      + ':{"type":"array","items":{"type":"number"}},"amplitude_db":{"type":"ar'
      + 'ray","items":{"type":"number"}}},"title":"Gaussian Decomposition"}'
    );

    Example : (''
      + '{"amplitude_lsb_high_power":[],"range_offset_sec_high_power":[],"ampli'
      + 'tude_lsb_low_power":[],"range_offset_sec_low_power":[],"amplitude_db":'
      + '[]}'
    );
  );

// Point cloud Georeferencing Information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud Georeferencing Information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"crs":{"type":"object","properties":{"name":{"type":"stri'
      + 'ng","description":"Coordinate reference system '
      + 'name"},"epsg":{"type":"integer","minimum":0,"description":"EPSG '
      + 'code"},"wkt":{"type":"string","description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)"}},"description":"Global Coordinate Reference System. Please '
      + 'note that only 3D Cartesian Coordinate Systems are allowed."},"pose":{'
      + '"type":"array","minItems":4,"maxItems":4,"description":"Coordinate '
      + 'Transformation Matrix to transform from File Coordinate System to '
      + 'Global Coordinate Reference System. 4x4 matrix stored as two '
      + 'dimensional array, row major order.","items":{"type":"array","minItems'
      + '":4,"maxItems":4,"description":"rows","items":{"type":"number","descri'
      + 'ption":"columns"}}}},"description":"Point cloud Georeferencing '
      + 'Information","title":"Geo Tag"}'
    );

    Example : (''
      + '{"crs":{"name":"WGS84 Geocentric","epsg":4978,"wkt":"GEOCCS[\"WGS84 Ge'
      + 'ocentric\",DATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.25722356'
      + '3,AUTHORITY[\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\'
      + '"Greenwich\",0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"M'
      + 'eter\",1.00000000000000000000,AUTHORITY[\"EPSG\",\"9001\"]],AXIS[\"X\"'
      + ',OTHER],AXIS[\"Y\",EAST],AXIS[\"Z\",NORTH],AUTHORITY[\"EPSG\",\"4978\"'
      + ']]"},"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,'
      + '4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847'
      + ',1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196'
      + '],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Geometric Scale Factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric Scale Factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"number","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'exclusiveMinimum":true,"minimum":0,"description":"Geometric Scale '
      + 'Factor applied to point coordinates"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"trajectory_file":{"type":"object","required":["file_exte'
      + 'nsion"],"properties":{"file_extension":{"type":"string","description":'
      + '"Trajectory file extension, without the leading '
      + 'dot"},"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)"}},"description":"Trajectory data used '
      + 'for georeferencing of the point cloud"},"socs_to_body_matrix":{"type":'
      + '"array","minItems":4,"maxItems":4,"description":"Coordinate '
      + 'Transformation Matrix to transform from Scanner''s Own Coordinate '
      + 'System to Body Coordinate System. 4x4 matrix stored as two dimensional'
      + ' array, row major order.","items":{"type":"array","minItems":4,"maxIte'
      + 'ms":4,"description":"rows","items":{"type":"number","description":"col'
      + 'umns"}}},"trajectory_offsets":{"type":"object","properties":{"offset_y'
      + 'aw":{"type":"number","description":"[deg]"},"offset_time":{"type":"num'
      + 'ber","description":"[s]"},"offset_pitch":{"type":"number","description'
      + '":"[deg]"},"offset_roll":{"type":"number","description":"[deg]"},"vers'
      + 'ion":{"type":"integer","description":"Meaning of offset values and how'
      + ' to apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(yaw_offset)*Ry(pitch_offset'
      + ')*Rx(roll_offset)"},"offset_height":{"type":"number","description":"[m'
      + ']"},"offset_north":{"type":"number","description":"[m]"},"offset_east"'
      + ':{"type":"number","description":"[m]"}},"description":"Correction '
      + 'offsets applied to the trajectory data"},"socs_to_rocs_matrix":{"type"'
      + ':"array","minItems":4,"maxItems":4,"description":"Coordinate '
      + 'Transformation Matrix to transform from Scanner''s Own Coordinate '
      + 'System to Record Coordinate System. 4x4 matrix stored as two '
      + 'dimensional array, row major order.","items":{"type":"array","minItems'
      + '":4,"maxItems":4,"description":"rows","items":{"type":"number","descri'
      + 'ption":"columns"}}},"body_coordinate_system_type":{"type":"string","en'
      + 'um":["NED","ENU"],"description":"BODY coordinate frame (NED: '
      + 'North-East-Down, ENU: East-North-Up), default: '
      + 'NED"}},"description":"Parameters used for georeferencing of the point '
      + 'cloud","title":"Georeferencing Parameters"}'
    );

    Example : (''
      + '{"trajectory_file":{"file_extension":"pofx","file_uuid":"93a03615-66c0'
      + '-4bea-8ff8-c577378fe660"},"socs_to_body_matrix":[[-0.269827776749716,-'
      + '0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051'
      + '7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,'
      + '0.0],[0.0,0.0,0.0,1.0]],"trajectory_offsets":{"offset_yaw":-0.45,"offs'
      + 'et_time":18.007,"offset_pitch":0.01,"offset_roll":0.03,"version":0,"of'
      + 'fset_height":-0.2,"offset_north":0.07,"offset_east":0.15},"body_coordi'
      + 'nate_system_type":"NED"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"additionalProperties":false,"description":"License keys for software'
      + ' features","type":"object","$schema":"http://json-schema.org/draft-04/'
      + 'schema#","title":"Software License Keys","patternProperties":{"^.*$":{'
      + '"type":"array","minItems":1,"description":"Each field of the object '
      + 'represents a feature and holds a list of license keys, where the field'
      + ' name is the feature '
      + 'name.","items":{"type":"string","description":"License key (example: '
      + '''46AE032A - 39882AC4 - 9EC0A184 - 6F163D73'')"}}}}'
    );

    Example : (''
      + '{"Full Waveform Analysis Topography":["0FD5FF07 - 011A1255 - 9F76CACA '
      + '- 8D2ED557"],"Full Waveform Analysis Topography with GPU '
      + 'support":["8AB44126 - 23B92250 - 16E2689F - '
      + '34EF7E7B"],"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73"],"MTA resolution":["468E020A - 39A922E4 - B681A184 - '
      + '673E3D72"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"modulation_depth":{"type":"number","minimum":0,"descript'
      + 'ion":"Depth of pulse position modulation in meter."},"zone_width":{"ty'
      + 'pe":"number","minimum":0,"description":"Width of a MTA zone in meter."'
      + '},"zone_count":{"type":"integer","minimum":0,"maximum":255,"descriptio'
      + 'n":"Maximum number of MTA zones."}},"description":"Parameters for MTA '
      + 'processing","title":"MTA Settings"}'
    );

    Example : (''
      + '{"modulation_depth":9.368514,"zone_width":149.896225,"zone_count":23}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["delta","content"],"description":"Lookup table for range '
      + 'correction based on raw range","type":"object","$schema":"http://json-'
      + 'schema.org/draft-04/schema#","properties":{"delta":{"type":"number","d'
      + 'escription":"Delta between table entries [m], first entry is at range '
      + '= 0 m"},"content":{"type":"array","minItems":1,"maxItems":2000,"descri'
      + 'ption":"Correction value [m] to be added to the raw '
      + 'range","items":{"type":"number"}}},"title":"Near Range Correction '
      + 'Table"}'
    );

    Example : (''
      + '{"delta":0.512,"content":[0.0]}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["amplitude","range_sigma","amplitude_sigma"],"description'
      + '":"Standard deviation for range and amplitude as a function of amplitu'
      + 'de","type":"object","$schema":"http://json-schema.org/draft-04/schema#'
      + '","properties":{"range_sigma":{"type":"array","description":"Sigma '
      + 'range [m]","items":{"type":"number"}},"amplitude":{"type":"array","des'
      + 'cription":"Amplitude [dB]","items":{"type":"number"}},"amplitude_sigma'
      + '":{"type":"array","description":"Sigma amplitude '
      + '[dB]","items":{"type":"number"}}},"title":"Noise Estimates"}'
    );

    Example : (''
      + '{"range_sigma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,'
      + '0.016,0.014],"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0'
      + '],"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.'
      + '432,0.39,0.354]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["range_minimum","range_maximum","amplitude_maximum"],"des'
      + 'cription":"Notch filter parameters for window glass echoes","type":"ob'
      + 'ject","$schema":"http://json-schema.org/draft-04/schema#","properties"'
      + ':{"amplitude_maximum":{"type":"number","minimum":0,"description":"Maxi'
      + 'mum amplitude '
      + '[dB]"},"range_maximum":{"type":"number","description":"Maximum range '
      + '[m]"},"range_minimum":{"type":"number","description":"Minimum range '
      + '[m]"}},"title":"Notch Filter"}'
    );

    Example : (''
      + '{"amplitude_maximum":18.0,"range_maximum":0.2,"range_minimum":-0.5}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["size"],"description":"Details about the pixels contained'
      + ' in the file","type":"object","$schema":"http://json-schema.org/draft-'
      + '04/schema#","properties":{"size":{"description":"Size of pixels in '
      + 'file coordinate system.","$ref":"#/definitions/pixel_size"},"size_llcs'
      + '":{"description":"Size of pixels in a locally levelled cartesian '
      + 'coordinate system (xy). This is only used for pixels based on a map pr'
      + 'ojection.","$ref":"#/definitions/pixel_size"}},"definitions":{"pixel_s'
      + 'ize":{"type":"array","minItems":2,"maxItems":2,"description":"Size of '
      + 'pixels.","items":{"type":"number","minimum":0,"description":"Length of'
      + ' pixel edge [m]."}}},"title":"Pixel Information"}'
    );

    Example : (''
      + '{"size":[0.5971642834779395,0.5971642834779395],"size_llcs":[0.5156575'
      + '252891171,0.5130835356683303]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["plane_patch_file_one","plane_patch_file_two"],"descripti'
      + 'on":"Details about the plane patch matching process","type":"object","'
      + '$schema":"http://json-schema.org/draft-04/schema#","properties":{"plan'
      + 'e_patch_file_two":{"description":"Reference to the plane patch file tw'
      + 'o","$ref":"#/definitions/file_reference"},"plane_patch_file_one":{"des'
      + 'cription":"Reference to the plane patch file one","$ref":"#/definition'
      + 's/file_reference"}},"definitions":{"file_reference":{"type":"object","'
      + 'required":["file_uuid","file_path"],"properties":{"file_uuid":{"type":'
      + '"string","description":"Plane patch file''s Universally Unique '
      + 'Identifier (RFC '
      + '4122)"},"file_path":{"type":"string","description":"Path of the plane '
      + 'patch file relative to the match file"}},"description":"Reference to a'
      + ' plane patch file"}},"title":"Plane Patch Matching"}'
    );

    Example : (''
      + '{"plane_patch_file_two":{"file_uuid":"fa47d509-a64e-49ce-8b14-ff3130fb'
      + 'efa9","file_path":"project.ptch"},"plane_patch_file_one":{"file_uuid":'
      + '"810f5d57-eccf-49ed-b07a-0cdd109b4213","file_path":"Record009_Line001/'
      + '191025_121410_Scanner_1.ptch"}}'
    );
  );

// Statistics about plane patches found by Plane Patch Extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by Plane Patch Extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"total_horizontal_area":{"type":"number","description":"s'
      + 'um of all plane patch areas projected to horizontal plane '
      + '[m\u00b2]"},"total_area":{"type":"number","description":"sum of all '
      + 'plane patch areas [m\u00b2]"}},"description":"Statistics about plane '
      + 'patches found by Plane Patch Extractor","title":"Plane Patch '
      + 'Statistics"}'
    );

    Example : (''
      + '{"total_horizontal_area":13954.601,"total_area":14007.965}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["settings","classes"],"description":"Settings and classes'
      + ' for plane slope classification","type":"object","$schema":"http://jso'
      + 'n-schema.org/draft-04/schema#","properties":{"settings":{"type":"objec'
      + 't","description":"Classification settings, details see documentation '
      + 'of rdbplanes","oneOf":[{"$ref":"#/definitions/method-1"},{"$ref":"#/de'
      + 'finitions/method-2"}]},"classes":{"type":"object","additionalPropertie'
      + 's":false,"description":"Class definition table","patternProperties":{"'
      + '^[0-9]+$":{"type":"string","description":"one field per class, field '
      + 'name is class number, field value is class name"}}}},"definitions":{"m'
      + 'ethod-1":{"type":"object","required":["plane_classification_method","m'
      + 'aximum_inclination_angle_horizontal"],"properties":{"maximum_inclinati'
      + 'on_angle_horizontal":{"type":"number","minimum":-360.0,"maximum":360.0'
      + ',"description":"maximum inclination angle of horizontal plane patches '
      + '[deg]"},"plane_classification_method":{"type":"integer","minimum":1,"m'
      + 'aximum":1,"description":"method ID '
      + '(=1)"}},"description":"Classification method 1"},"method-2":{"type":"o'
      + 'bject","required":["plane_classification_method","sloping_plane_classe'
      + 's_minimum_angle","sloping_plane_classes_maximum_angle"],"properties":{'
      + '"sloping_plane_classes_minimum_angle":{"type":"number","minimum":-360.'
      + '0,"maximum":360.0,"description":"minimum inclination angle of sloping '
      + 'plane patches [deg]"},"sloping_plane_classes_maximum_angle":{"type":"n'
      + 'umber","minimum":-360.0,"maximum":360.0,"description":"maximum '
      + 'inclination angle of sloping plane patches [deg]"},"plane_classificati'
      + 'on_method":{"type":"integer","minimum":2,"maximum":2,"description":"me'
      + 'thod ID (=2)"}},"description":"Classification method '
      + '2"}},"title":"Plane Slope Class Info"}'
    );

    Example : (''
      + '{"settings":{"sloping_plane_classes_minimum_angle":10.0,"sloping_plane'
      + '_classes_maximum_angle":70.0,"plane_classification_method":2},"classes'
      + '":{"8":"vertical, pointing north","13":"sloping, pointing down and '
      + 'west","3":"sloping, pointing up and south","4":"sloping, pointing up '
      + 'and north","2":"sloping, pointing up and east","1":"horizontal, '
      + 'pointing up","14":"horizontal, pointing down","6":"vertical, pointing '
      + 'east","12":"sloping, pointing down and north","5":"sloping, pointing '
      + 'up and west","9":"vertical, pointing west","10":"sloping, pointing '
      + 'down and east","11":"sloping, pointing down and south","7":"vertical, '
      + 'pointing south"}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"additionalProperties":false,"description":"Grouping and sorting of '
      + 'point attributes for visualization purposes","type":"object","$schema"'
      + ':"http://json-schema.org/draft-04/schema#","title":"Point Attribute Gr'
      + 'oups","patternProperties":{"^.*$":{"type":"array","minItems":1,"descri'
      + 'ption":"Each field of the object represents a point attribute group '
      + 'and holds a list of point attributes, where the field name is the '
      + 'group name.","items":{"type":"string","description":"Point attribute '
      + 'full name or name pattern (perl regular expression syntax)"}}}}'
    );

    Example : (''
      + '{"Secondary '
      + 'Attributes":["riegl.mirror_facet","riegl.waveform_available"],"Primary'
      + ' Attributes":["riegl.reflectance","riegl.amplitude","riegl.deviation"]'
      + ',"Time":["riegl.timestamp"],"Coordinates/Vectors":["riegl.xyz","riegl.'
      + 'range","riegl.theta","riegl.phi"],"Other '
      + 'Attributes":["riegl.selected","riegl.visible"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"field_of_application":{"type":"string","enum":["unknown"'
      + ',"SLS","TLS","KLS","MLS","ULS","ALS","BLS","ILS"],"description":"Field'
      + ' of application"},"comments":{"type":"string","description":"Comments"'
      + '},"project":{"type":"string","description":"Project '
      + 'name"}},"description":"Details about point cloud files","title":"Point'
      + ' Cloud Information"}'
    );

    Example : (''
      + '{"field_of_application":"ALS","comments":"Line 3","project":"Campaign '
      + '4"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["orientation"],"description":"Estimated position and '
      + 'orientation information as measured by GNSS, IMU or inclination sensor'
      + 's","type":"object","$schema":"http://json-schema.org/draft-04/schema#"'
      + ',"properties":{"orientation":{"type":"object","required":["roll","pitc'
      + 'h","yaw","roll_accuracy","pitch_accuracy","yaw_accuracy"],"properties"'
      + ':{"pitch":{"type":"number","minimum":-360,"maximum":360,"description":'
      + '"Pitch angle about scanner Y-axis [deg]"},"pitch_accuracy":{"type":"nu'
      + 'mber","minimum":0,"exclusiveMinimum":true,"description":"Pitch angle '
      + 'accuracy [deg]"},"roll":{"type":"number","minimum":-360,"maximum":360,'
      + '"description":"Roll angle about scanner X-axis [deg]"},"yaw":{"type":"'
      + 'number","minimum":-360,"maximum":360,"description":"Yaw angle about '
      + 'scanner Z-axis [deg]"},"yaw_accuracy":{"type":"number","minimum":0,"ex'
      + 'clusiveMinimum":true,"description":"Yaw angle accuracy [deg]"},"roll_a'
      + 'ccuracy":{"type":"number","minimum":0,"exclusiveMinimum":true,"descrip'
      + 'tion":"Roll angle accuracy [deg]"}},"description":"Orientation values '
      + 'and orientation accuracies, measured with IMU or inclination sensors."'
      + '},"barometric_height_amsl":{"type":"number","description":"Altitude '
      + 'determined based on the atmospheric pressure according to the standard'
      + ' atmosphere laws [m]."},"position":{"type":"object","required":["coord'
      + 'inate_1","coordinate_2","coordinate_3","horizontal_accuracy","vertical'
      + '_accuracy","crs"],"properties":{"horizontal_accuracy":{"type":"number"'
      + ',"minimum":0,"exclusiveMinimum":true,"description":"Horizontal '
      + 'accuracy '
      + '[m]"},"coordinate_2":{"type":"number","description":"Coordinate 2 as '
      + 'defined by axis 2 of the specified CRS (e.g., Y, '
      + 'Longitude)"},"coordinate_1":{"type":"number","description":"Coordinate'
      + ' 1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)"},"cr'
      + 's":{"type":"object","required":["epsg"],"properties":{"epsg":{"type":"'
      + 'integer","minimum":0,"description":"EPSG '
      + 'code"},"wkt":{"type":"string","description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)"}},"description":"Global Coordinate Reference System"},"vertic'
      + 'al_accuracy":{"type":"number","minimum":0,"exclusiveMinimum":true,"des'
      + 'cription":"Vertical accuracy '
      + '[m]"},"coordinate_3":{"type":"number","description":"Coordinate 3 as '
      + 'defined by axis 3 of the specified CRS (e.g., Z, '
      + 'Altitude)"}},"description":"Position coordinates and position accuracy'
      + ' values as measured by GNSS in the specified Coordinate Reference '
      + 'System (CRS)"}},"title":"Pose Estimation"}'
    );

    Example : (''
      + '{"orientation":{"pitch":1.509153024827064,"pitch_accuracy":0.009433783'
      + '936875745,"roll":3.14743073066123,"yaw":101.87293630292045,"yaw_accura'
      + 'cy":1.0094337839368757,"roll_accuracy":0.009433783936875745},"barometr'
      + 'ic_height_amsl":386.7457796227932,"position":{"horizontal_accuracy":0.'
      + '810699999332428,"coordinate_2":15.645033406,"coordinate_1":48.65579947'
      + '3,"crs":{"epsg":4979,"wkt":"GEOGCS[\"WGS84 / Geographic\",DATUM[\"WGS8'
      + '4\",SPHEROID[\"WGS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\"'
      + '7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.00000000'
      + '00000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"Degree\",0.0174532925199'
      + '4329547,AUTHORITY[\"EPSG\",\"9102\"]],AXIS[\"Latitude\",NORTH],AXIS[\"'
      + 'Longitude\",EAST],AUTHORITY[\"EPSG\",\"4979\"]]"},"vertical_accuracy":'
      + '1.3314999341964722,"coordinate_3":362.7124938964844}}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["gyroscope","accelerometer","magnetic_field_sensor"],"des'
      + 'cription":"Details on position and orientation sensors","type":"object'
      + '","$schema":"http://json-schema.org/draft-04/schema#","properties":{"g'
      + 'yroscope":{"type":"object","required":["unit","x_axis","y_axis","z_axi'
      + 's","offset","origin","relative_nonlinearity"],"properties":{"x_axis":{'
      + '"description":"Sensitive X axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"origin":{"description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0","$ref":"#/definitions/vector"},"z_axis":{"description":"Sensitive Z'
      + ' axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"y_axis":{"description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0","$ref":"#/definitions/vector"},"un'
      + 'it":{"type":"number","minimum":0,"exclusiveMinimum":true,"description"'
      + ':"Unit of raw data and calibration values, 1 LSB in '
      + 'rad/s"},"offset":{"description":"Value to be subtracted from raw '
      + 'measurement values","$ref":"#/definitions/vector"},"relative_nonlinear'
      + 'ity":{"description":"Relative nonlinearity, dimensionless","$ref":"#/d'
      + 'efinitions/vector"}},"description":"Gyroscope details"},"magnetic_fiel'
      + 'd_sensor":{"type":"object","required":["unit","x_axis","y_axis","z_axi'
      + 's","offset","fixed","relative_nonlinearity"],"properties":{"x_axis":{"'
      + 'description":"Sensitive X axis of sensor at frame angle = 0","$ref":"#'
      + '/definitions/vector"},"relative_nonlinearity":{"description":"Relative'
      + ' nonlinearity, dimensionless","$ref":"#/definitions/vector"},"z_axis":'
      + '{"description":"Sensitive Z axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"y_axis":{"description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0","$ref":"#/definitions/vector"},"un'
      + 'it":{"type":"number","minimum":0,"exclusiveMinimum":true,"description"'
      + ':"Unit of raw data and calibration values, 1 LSB in '
      + 'nT"},"offset":{"description":"Value to be subtracted from raw '
      + 'measurement values","$ref":"#/definitions/vector"},"fixed":{"descripti'
      + 'on":"Distortion of magnetic field caused by non-rotating scanner '
      + 'part","$ref":"#/definitions/vector"}},"description":"Magnetic Field '
      + 'Sensor details"},"accelerometer":{"type":"object","required":["unit","'
      + 'x_axis","y_axis","z_axis","offset","origin","relative_nonlinearity"],"'
      + 'properties":{"x_axis":{"description":"Sensitive X axis of sensor at '
      + 'frame angle = '
      + '0","$ref":"#/definitions/vector"},"origin":{"description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0","$ref":"#/definitions/vector"},"z_axis":{"description":"Sensitive Z'
      + ' axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"y_axis":{"description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0","$ref":"#/definitions/vector"},"un'
      + 'it":{"type":"number","minimum":0,"exclusiveMinimum":true,"description"'
      + ':"Unit of raw data and calibration values, 1 LSB in 9.81 '
      + 'm/s\u00b2"},"offset":{"description":"Value to be subtracted from raw '
      + 'measurement values","$ref":"#/definitions/vector"},"relative_nonlinear'
      + 'ity":{"description":"Relative nonlinearity, dimensionless","$ref":"#/d'
      + 'efinitions/vector"}},"description":"Accelerometer details"}},"definiti'
      + 'ons":{"vector":{"type":"array","minItems":3,"maxItems":3,"items":{"typ'
      + 'e":"number","description":"Index 0=X, 1=Y, 2=Z '
      + 'component"}}},"title":"Pose Sensors"}'
    );

    Example : (''
      + '{"gyroscope":{"x_axis":[-121.195556640625,0.8219714164733887,0.2313031'
      + '703233719],"origin":[0.026900000870227814,-0.03999999910593033,-0.0895'
      + '0000256299973],"z_axis":[0.555869996547699,119.22135162353516,0.467585'
      + '027217865],"y_axis":[-0.440765917301178,-0.7897399663925171,119.589477'
      + '5390625],"unit":0.00014544410805683583,"offset":[-50.92609786987305,14'
      + '6.15643310546875,62.4327278137207],"relative_nonlinearity":[2.88817631'
      + '1444113e-07,1.06274164579645e-07,-1.7186295080634935e-39]},"magnetic_f'
      + 'ield_sensor":{"x_axis":[-0.011162743903696537,-2.315962774446234e-05,0'
      + '.00016818844596855342],"relative_nonlinearity":[0.0,0.0,0.0],"z_axis":'
      + '[0.00041987866279669106,7.876977906562388e-05,0.011407104320824146],"y'
      + '_axis":[0.00027888521435670555,-0.011427424848079681,-5.20482972206082'
      + '2e-05],"unit":91.74311828613281,"offset":[-23812.052734375,5606.576660'
      + '15625,2493.28125],"fixed":[-1576.010498046875,1596.081787109375,0.0]},'
      + '"accelerometer":{"x_axis":[-15008.123046875,56.956390380859375,-60.517'
      + '5666809082],"origin":[0.026900000870227814,-0.03999999910593033,-0.089'
      + '50000256299973],"z_axis":[1.639882206916809,15166.744140625,-116.99742'
      + '889404297],"y_axis":[-7.027288913726807,-44.12333679199219,14952.37011'
      + '71875],"unit":6.666666740784422e-05,"offset":[-733.3636474609375,58.96'
      + '9032287597656,1060.2550048828125],"relative_nonlinearity":[0.0,0.0,0.0'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["length","num_mod_ampl","pulse_interval"],"description":"'
      + 'Laser pulse position modulation used for MTA resolution","type":"objec'
      + 't","$schema":"http://json-schema.org/draft-04/schema#","properties":{"'
      + 'pulse_interval":{"type":"array","description":"Explicit table of the '
      + 'pulse position modulation used for MTA resolution. Table gives times '
      + 'between successive laser pulses in seconds.","items":{"type":"number",'
      + '"minimum":0}},"length":{"type":"integer","minimum":0,"maximum":255,"de'
      + 'scription":"Length of code"},"code_phase_mode":{"type":"integer","mini'
      + 'mum":0,"maximum":255,"description":"0: no synchronization, 1: toggle '
      + 'between 2 phases, 2: increment with phase_increment"},"phase_step":{"t'
      + 'ype":"integer","minimum":0,"maximum":255,"description":"Step width in '
      + 'phase of modulation code from line to line"},"num_mod_ampl":{"type":"i'
      + 'nteger","minimum":0,"maximum":255,"description":"Number of different '
      + 'modulation amplitudes (2: binary modulation)"}},"title":"Pulse '
      + 'Position Modulation"}'
    );

    Example : (''
      + '{"pulse_interval":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06'
      + ',2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82'
      + '1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e'
      + '-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2'
      + '.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218'
      + '75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0'
      + '6],"length":31,"code_phase_mode":2,"phase_step":5,"num_mod_ampl":2}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["minimum","average","maximum","std_dev"],"description":"S'
      + 'tatistics about target distance wrt. SOCS origin","type":"object","$sc'
      + 'hema":"http://json-schema.org/draft-04/schema#","properties":{"minimum'
      + '":{"type":"number","description":"Minimum '
      + 'value"},"average":{"type":"number","description":"Average '
      + 'value"},"maximum":{"type":"number","description":"Maximum '
      + 'value"},"std_dev":{"type":"number","description":"Standard '
      + 'deviation"}},"title":"Range Statistics"}'
    );

    Example : (''
      + '{"minimum":0.919,"average":15.49738,"maximum":574.35,"std_dev":24.349}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Receiver Internals","type":"object","$schema":"http://'
      + 'json-schema.org/draft-04/schema#","properties":{"t":{"type":"object","'
      + 'additionalProperties":false,"patternProperties":{"^[0-9]+$":{"descript'
      + 'ion":"one field per channel, field name is channel index","$ref":"#/de'
      + 'finitions/fp"}}},"mw":{"type":"number","minimum":0,"maximum":4095,"des'
      + 'cription":"Maximum weight","exclusiveMinimum":true},"a":{"type":"array'
      + '","minItems":1,"maxItems":256,"items":{"type":"number"},"description":'
      + '"Amplitude [dB]"},"ns":{"type":"integer","minimum":0,"maximum":4095,"d'
      + 'escription":"Number of samples"},"sr":{"type":"number","minimum":0,"ex'
      + 'clusiveMinimum":true,"description":"Sample rate [Hz]"},"nt":{"type":"i'
      + 'nteger","minimum":0,"maximum":255,"description":"Number of traces"},"t'
      + 'bl":{"type":"array","minItems":1,"items":{"$ref":"#/definitions/fp_tab'
      + 'le"},"description":"various internal '
      + 'data"},"ex":{"type":"object","description":"DEPRECATED, use '
      + '''riegl.exponential_decomposition'' instead"},"si":{"type":"number","min'
      + 'imum":0,"maximum":255,"description":"Start index (hw_start)"}},"defini'
      + 'tions":{"fp":{"type":"object","required":["s","w"],"properties":{"s":{'
      + '"type":"array","minItems":1,"maxItems":256,"items":{"type":"array","mi'
      + 'nItems":1,"maxItems":4096,"items":{"type":"number"}}},"w":{"type":"arr'
      + 'ay","minItems":1,"maxItems":256,"items":{"type":"array","minItems":5,"'
      + 'maxItems":5,"items":{"type":"number"}}}},"description":"Fingerprint '
      + 'values"},"fp_table":{"type":"object","desription":"scanner internal da'
      + 'ta","properties":{"ny":{"type":"integer","min":1,"description":"number'
      + ' of y entries","max":2048},"nx":{"type":"integer","min":1,"description'
      + '":"number of x entries","max":2048},"tv":{"type":"array","minItems":1,'
      + '"maxItems":2048,"items":{"oneOf":[{"$ref":"#/definitions/fp_table_row"'
      + '},{"type":"number"}]}},"tc":{"type":"integer","min":0,"description":"t'
      + 'able data type '
      + 'code","max":255},"ch":{"type":"integer","min":0,"description":"channel'
      + ' number","max":255}},"required":["ch","tc","nx","ny","tv"]},"fp_table_'
      + 'row":{"type":"array","minItems":1,"maxItems":2048,"items":{"type":"num'
      + 'ber"}}},"title":"Receiver Internals"}'
    );

    Example : (''
      + '{"t":{"0":{"s":[[1.23,4.56],[7.89,0.12]],"w":[[78,86,126,134,31],[78,8'
      + '6,126,134,31]]},"1":{"s":[[1.23,4.56],[7.89,0.12]],"w":[[78,86,126,134'
      + ',31],[78,86,126,134,31]]}},"mw":31,"a":[-1.55],"ns":400,"sr":795999700'
      + '0.0,"nt":128,"tbl":[{"ny":2,"nx":5,"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,'
      + '5.5]],"tc":1,"ch":0}],"si":48}'
    );
  );

// List of names of the records
const
  RDB_RIEGL_RECORD_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.record_names';
    Title       : 'Record Names';
    Description : 'List of names of the records';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"names":{"type":"array","description":"List of record '
      + 'names. The name of a record is the {riegl.id}th element of this list. '
      + 'The number of elements must correspond to the maximum riegl.id '
      + 'occurring in this '
      + 'file.","items":{"type":"string","description":"Record '
      + 'name"}}},"description":"List of names of the records","title":"Record '
      + 'Names"}'
    );

    Example : (''
      + '{"names":["Name of first record","Name of second record","Name of '
      + 'third record","Name of fourth record"]}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["delta","content"],"description":"Lookup table for '
      + 'reflectance calculation based on amplitude and range","type":"object",'
      + '"$schema":"http://json-schema.org/draft-04/schema#","properties":{"del'
      + 'ta":{"type":"number","description":"Delta between table entries [m], '
      + 'first entry is at range = 0 m"},"content":{"type":"array","minItems":1'
      + ',"maxItems":2000,"description":"Correction value [dB] to be added to '
      + 'the amplitude","items":{"type":"number"}}},"title":"Reflectance '
      + 'Calculation Table"}'
    );

    Example : (''
      + '{"delta":0.150918,"content":[-33.01]}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-range reflectance correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["ranges_m","line_angles_deg","reflectance_correction_db"]'
      + ',"description":"Range-dependent and scan-angle-dependent correction of'
      + ' reflectance reading","type":"object","$schema":"http://json-schema.or'
      + 'g/draft-04/schema#","properties":{"ranges_m":{"type":"array","descript'
      + 'ion":"Range [m]","items":{"type":"number"}},"line_angles_deg":{"type":'
      + '"array","description":"Angle [deg]","items":{"type":"number"}},"reflec'
      + 'tance_correction_db":{"type":"array","description":"Near range '
      + 'reflectance correction in dB as a function of range over '
      + 'angle","items":{"type":"array","description":"rows (each array '
      + 'corresponds to a '
      + 'range)","items":{"type":"number","description":"columns (each value '
      + 'corresponds to an angle)"}}}},"title":"Near-range reflectance '
      + 'correction"}'
    );

    Example : (''
      + '{"ranges_m":[0.0,1.0,2.0,3.0],"line_angles_deg":[0.0,0.5,1.0,1.5,1.0,2'
      + '.0,2.5,3.0,3.5,4.0],"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,'
      + '0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.'
      + '8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,'
      + '0.1,0.05,0.01]]}'
    );
  );

// Scan Pattern Description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan Pattern Description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"re'
      + 'ctangular":{"type":"object","required":["phi_start","phi_stop","phi_in'
      + 'crement","theta_start","theta_stop","theta_increment"],"properties":{"'
      + 'program":{"$ref":"#/definitions/program"},"phi_increment":{"type":"num'
      + 'ber","minimum":0.0,"maximum":90.0,"description":"Increment of phi '
      + 'angle in SOCS [deg]"},"theta_stop":{"type":"number","minimum":0.0,"max'
      + 'imum":180.0,"description":"Stop theta angle in SOCS [deg]"},"phi_start'
      + '":{"type":"number","minimum":0.0,"maximum":360.0,"description":"Start '
      + 'phi angle in SOCS [deg]"},"phi_stop":{"type":"number","minimum":0.0,"m'
      + 'aximum":720.0,"description":"Stop phi angle in SOCS [deg]"},"theta_sta'
      + 'rt":{"type":"number","minimum":0.0,"maximum":180.0,"description":"Star'
      + 't theta angle in SOCS [deg]"},"theta_increment":{"type":"number","mini'
      + 'mum":0.0,"maximum":90.0,"description":"Increment of theta angle in '
      + 'SOCS [deg]"}},"description":"Rectangular Field Of View Scan Pattern"},'
      + '"segments":{"type":"object","required":["list"],"properties":{"program'
      + '":{"$ref":"#/definitions/program"},"list":{"type":"array","items":{"ty'
      + 'pe":"object","required":["start","stop","increment"],"properties":{"in'
      + 'crement":{"type":"number","minimum":0.0,"maximum":90.0,"description":"'
      + 'Increment of angle in SOCS [deg]"},"start":{"type":"number","minimum":'
      + '0.0,"maximum":360.0,"description":"Start angle in SOCS [deg]"},"stop":'
      + '{"type":"number","minimum":0.0,"maximum":720.0,"description":"Stop '
      + 'angle in SOCS [deg]"}},"description":"Line Scan '
      + 'Segment"}}},"description":"Segmented Line Scan Pattern"},"line":{"type'
      + '":"object","required":["start","stop","increment"],"properties":{"incr'
      + 'ement":{"type":"number","minimum":0.0,"maximum":90.0,"description":"In'
      + 'crement of angle in SOCS [deg]"},"program":{"$ref":"#/definitions/prog'
      + 'ram"},"start":{"type":"number","minimum":0.0,"maximum":360.0,"descript'
      + 'ion":"Start angle in SOCS [deg]"},"stop":{"type":"number","minimum":0.'
      + '0,"maximum":720.0,"description":"Stop angle in SOCS '
      + '[deg]"}},"description":"Line Scan Pattern"}},"definitions":{"program":'
      + '{"type":"object","required":["name"],"properties":{"name":{"type":"str'
      + 'ing","description":"Name of measurement program"},"laser_prr":{"type":'
      + '"number","minimum":0,"exclusiveMinimum":false,"description":"Laser '
      + 'Pulse Repetition Rate [Hz]"}},"description":"Measurement '
      + 'program"}},"description":"Scan Pattern Description","title":"Scan '
      + 'Pattern"}'
    );

    Example : (''
      + '{"rectangular":{"program":{"name":"High Speed","laser_prr":100000.0},"'
      + 'phi_increment":0.04,"theta_stop":130.0,"phi_start":45.0,"phi_stop":270'
      + '.0,"theta_start":30.0,"theta_increment":0.04}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"shot_file":{"type":"object","required":["file_extension"'
      + '],"properties":{"file_extension":{"type":"string","description":"Shot '
      + 'file extension, without the leading '
      + 'dot"},"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)"}}}},"description":"Details about laser '
      + 'shot files","title":"Shot Information"}'
    );

    Example : (''
      + '{"shot_file":{"file_extension":"sodx","file_uuid":"26a00815-67c0-4bff-'
      + '8fe8-c577378fe663"}}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Conversion of background radiation raw values to '
      + 'temperatures in \u00b0C","type":"object","$schema":"http://json-schema'
      + '.org/draft-04/schema#","properties":{"InGaAs_Si_Difference":{"descript'
      + 'ion":"Conversion table for InGaAs - Si difference","$ref":"#/definitio'
      + 'ns/conversion_table"},"Si":{"description":"Conversion table for Si cha'
      + 'nnel","$ref":"#/definitions/conversion_table"},"InGaAs":{"description"'
      + ':"Conversion table for InGaAs channel","$ref":"#/definitions/conversio'
      + 'n_table"}},"definitions":{"conversion_table":{"type":"object","require'
      + 'd":["value","temperature"],"properties":{"value":{"type":"array","desc'
      + 'ription":"LSB [1]","items":{"type":"number"}},"temperature":{"type":"a'
      + 'rray","description":"Temperature '
      + '[\u00b0C]","items":{"type":"number"}}}}},"title":"Temperature '
      + 'Calculation Table"}'
    );

    Example : (''
      + '{"InGaAs_Si_Difference":{"value":[1000.0,1100.090029602954,1200.044251'
      + '83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13'
      + '27555162209,1700.0869777520065,1800.0411999877924],"temperature":[1749'
      + '.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17'
      + '49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109'
      + '2,1622.3944822534868]},"Si":{"value":[0.0,64.00097659230323,128.001953'
      + '1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005'
      + '8595538194,448.0068361461226,512.0078127384259],"temperature":[546.300'
      + '048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60'
      + '4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0'
      + '002936624203]},"InGaAs":{"value":[0.0,64.00097659230323,128.0019531846'
      + '065,192.0029297769097,256.0039063692129,320.00488296151616,384.0058595'
      + '538194,448.0068361461226,512.0078127384259],"temperature":[307.2219672'
      + '2535614,309.1153478247277,311.1188086915047,313.10025350480055,315.213'
      + '7946389828,317.2172555057597,319.2207163725366,321.2021611858325,323.3'
      + '157023200148]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["epoch","source"],"description":"Base of timestamps (epoc'
      + 'h)","type":"object","$schema":"http://json-schema.org/draft-04/schema#'
      + '","properties":{"epoch":{"type":"string","description":"Date and time '
      + 'of timestamp ''0'' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:'
      + '00)."},"system":{"type":"string","enum":["unknown","UTC","GPS"],"descr'
      + 'iption":"Time system (time standard)"},"source":{"type":"string","enum'
      + '":["unknown","RTC","GNSS"],"description":"Timestamp '
      + 'source"}},"title":"Time Base"}'
    );

    Example : (''
      + '{"epoch":"2015-10-27T00:00:00+00:00","system":"UTC","source":"GNSS"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["time_interval","navigation_frame"],"description":"Detail'
      + 's about position+orientation files","type":"object","$schema":"http://'
      + 'json-schema.org/draft-04/schema#","properties":{"navigation_frame":{"t'
      + 'ype":"string","enum":["unknown","NED","ENU"],"description":"Navigation'
      + ' frame (NED: North-East-Down, ENU: '
      + 'East-North-Up)"},"company":{"type":"string","description":"Company nam'
      + 'e"},"field_of_application":{"type":"string","enum":["unknown","SLS","T'
      + 'LS","KLS","MLS","ULS","ALS","BLS","ILS"],"description":"Field of appli'
      + 'cation"},"time_interval":{"type":"object","required":["minimum","avera'
      + 'ge","maximum","std_dev"],"properties":{"minimum":{"type":"number","des'
      + 'cription":"Minimum time interval '
      + '[s]"},"average":{"type":"number","description":"Average time interval '
      + '[s]"},"maximum":{"type":"number","description":"Maximum time interval '
      + '[s]"},"std_dev":{"type":"number","description":"Standard deviation of '
      + 'intervals [s]"}},"description":"Time interval '
      + 'statistics"},"software":{"type":"string","description":"Software that '
      + 'calculated the trajectory (this may be the same or different software '
      + 'than the one that created the '
      + 'file)"},"device":{"type":"string","description":"Navigation device, '
      + 'e.g. '
      + 'name/type/serial"},"settings":{"type":"string","description":"Settings'
      + ' used to calculate the trajectory (descriptive '
      + 'text)"},"location":{"type":"string","description":"Project location, '
      + 'e.g. '
      + 'city/state/country"},"project":{"type":"string","description":"Project'
      + ' name"}},"title":"Trajectory Information"}'
    );

    Example : (''
      + '{"navigation_frame":"NED","company":"RIEGL LMS","field_of_application"'
      + ':"MLS","time_interval":{"minimum":0.00500032,"average":0.00500053,"max'
      + 'imum":0.005004883,"std_dev":5.51e-07},"software":"Navigation Software '
      + 'XYZ","device":"IMU Model 12/1, Serial# '
      + '12345","settings":"default","location":"Horn","project":"Campaign 3"}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"vertex_file":{"type":"object","required":["file_extensio'
      + 'n"],"properties":{"file_extension":{"type":"string","description":"Ver'
      + 'tex file extension, without the leading '
      + 'dot"},"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)"}}}},"description":"Details about vertex '
      + 'file","title":"Vertex Information"}'
    );

    Example : (''
      + '{"vertex_file":{"file_extension":"vtx","file_uuid":"51534d95-d71f-4f36'
      + '-ae1a-3e63a21fd1c7"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the voxels contained in the file","type"'
      + ':"object","$schema":"http://json-schema.org/draft-04/schema#","definit'
      + 'ions":{"voxel_size":{"type":"array","minItems":3,"maxItems":3,"items":'
      + '{"$ref":"#/definitions/edge_length"},"description":"Size of voxels."},'
      + '"shape_thresholds":{"type":"object","required":["plane","line"],"prope'
      + 'rties":{"line":{"type":"number","minimum":1,"exclusiveMinimum":true,"d'
      + 'escription":"If the biggest eigenvalue is bigger than the median '
      + 'eigenvalue * line_threshold, the voxel is considered a line."},"plane"'
      + ':{"type":"number","exclusiveMinimum":true,"description":"If the '
      + 'smallest eigenvalue is smaller than the median eigenvalue * '
      + 'plane_threshold, the voxel is considered a plane.","minimum":0,"maximu'
      + 'm":1,"exclusiveMaximum":true}},"description":"Thresholds used to '
      + 'compute the voxel''s shape_id value."},"edge_length":{"type":"number","'
      + 'minimum":0,"exclusiveMinimum":true,"description":"Length of voxel edge'
      + ' [m]."},"voxel_origin_point":{"type":"array","minItems":3,"maxItems":3'
      + ',"description":"Origin point for all voxel indices in voxel CRS.","ite'
      + 'ms":{"type":"number"}},"voxel_size_cubic":{"type":"number","$ref":"#/d'
      + 'efinitions/edge_length"},"voxel_type":{"default":"centroid","enum":["c'
      + 'enter","centroid","index"],"description":"Whether a point in a voxel '
      + 'represents its center or its centroid. If type is <tt>index</tt> there'
      + ' is no point but only an integer voxel index."},"voxel_origin_enum":{"'
      + 'default":"corner","enum":["center","corner"],"description":"Defines '
      + 'whether the voxel''s center or a corner is placed on CRS origin <tt>(0/'
      + '0/0)</tt>."}},"oneOf":[{"required":["size","voxel_origin","voxel_type"'
      + '],"properties":{"size":{"description":"Size of voxels in file '
      + 'coordinate system.","oneOf":[{"$ref":"#/definitions/voxel_size"},{"$re'
      + 'f":"#/definitions/voxel_size_cubic"}]},"voxel_type":{"$ref":"#/definit'
      + 'ions/voxel_type"},"voxel_origin":{"$ref":"#/definitions/voxel_origin_e'
      + 'num"},"shape_thresholds":{"$ref":"#/definitions/shape_thresholds"}},"a'
      + 'dditionalProperties":false},{"required":["reference_point","size_llcs"'
      + ',"size","voxel_origin","voxel_type"],"properties":{"size":{"descriptio'
      + 'n":"Size of voxels in file coordinate system.","$ref":"#/definitions/v'
      + 'oxel_size"},"reference_point":{"type":"array","minItems":2,"maxItems":'
      + '2,"items":{"type":"number","minimum":-180,"maximum":180},"description"'
      + ':"Point in WGS84 geodetic decimal degree (EPSG:4326) that was used to '
      + 'compute the projection distortion parameters. The coefficient order is'
      + ' latitude, longitude. Only voxels with corresponding geo_tag, '
      + 'voxel_size and reference_point can be reliably processed together. '
      + 'This entry is available for voxel files in projected CRS '
      + 'only."},"size_llcs":{"description":"Size of voxels in a locally '
      + 'levelled cartesian coordinate system (xyz). This is only used for '
      + 'voxels based on a map projection.","$ref":"#/definitions/voxel_size"},'
      + '"shape_thresholds":{"$ref":"#/definitions/shape_thresholds"},"voxel_or'
      + 'igin":{"oneOf":[{"$ref":"#/definitions/voxel_origin_enum"},{"descripti'
      + 'on":"The base point of the voxel grid. Used together with '
      + '<tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual point c'
      + 'oordinates.","$ref":"#/definitions/voxel_origin_point"}]},"voxel_type"'
      + ':{"$ref":"#/definitions/voxel_type"}},"additionalProperties":false}],"'
      + 'title":"Voxel Information"}'
    );

    Example : (''
      + '{"size":[0.5971642834779395,0.5971642834779395,0.5143705304787237],"re'
      + 'ference_point":[48,16],"size_llcs":[0.5156575252891171,0.5130835356683'
      + '303,0.5143705304787237],"shape_thresholds":{"line":6,"plane":0.16},"vo'
      + 'xel_origin":"corner","voxel_type":"centroid"}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["num_shots","mta_zone"],"description":"Settings for '
      + 'waveform averaging","type":"object","$schema":"http://json-schema.org/'
      + 'draft-04/schema#","properties":{"mta_zone":{"type":"integer","minimum"'
      + ':1,"description":"Fixed MTA zone for averaging."},"num_shots":{"type":'
      + '"integer","minimum":1,"description":"Number of consecutive shots to be'
      + ' used for averaging."},"trim":{"type":"number","minimum":0,"default":0'
      + ',"maximum":0.5,"description":"Percentage for robust '
      + 'averaging."}},"title":"Waveform Averaging Settings"}'
    );

    Example : (''
      + '{"mta_zone":1,"num_shots":7,"trim":0.05}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["sample_block_file","sample_data_files"],"description":"D'
      + 'etails about waveform files","type":"object","$schema":"http://json-sc'
      + 'hema.org/draft-04/schema#","properties":{"sample_data_files":{"type":"'
      + 'array","items":{"type":"object","required":["channel","channel_name","'
      + 'sample_interval","sample_bits","laser_wavelength","delta_st","file_ext'
      + 'ension"],"properties":{"delta_st":{"type":"number","description":"rese'
      + 'rved"},"file_extension":{"type":"string","description":"Sample data '
      + 'file extension, without the leading '
      + 'dot"},"channel_name":{"type":"string","description":"Sample block '
      + 'channel name"},"laser_wavelength":{"type":"number","minimum":0,"exclus'
      + 'iveMinimum":false,"description":"Laser wavelength in meters (0 = unkno'
      + 'wn)"},"channel":{"minimum":0,"exclusiveMinimum":false,"description":"S'
      + 'ample block channel number (255 = invalid)","type":"integer","maximum"'
      + ':255,"exclusiveMaximum":false},"file_uuid":{"type":"string","descripti'
      + 'on":"File''s Universally Unique Identifier (RFC 4122)"},"sample_bits":{'
      + '"minimum":0,"exclusiveMinimum":false,"description":"Bitwidth of '
      + 'samples (e.g. 10 bit, 12 bit)","type":"integer","maximum":32,"exclusiv'
      + 'eMaximum":false},"sample_interval":{"type":"number","minimum":0,"exclu'
      + 'siveMinimum":false,"description":"Sampling interval in seconds"}}}},"s'
      + 'ample_block_file":{"type":"object","required":["file_extension"],"prop'
      + 'erties":{"file_extension":{"type":"string","description":"Sample block'
      + ' file extension, without the leading '
      + 'dot"},"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)"}}},"range_offset_m":{"type":"number","description":"Calibrated '
      + 'device specific waveform data range offset in '
      + 'meters."}},"title":"Waveform Information"}'
    );

    Example : (''
      + '{"sample_data_files":[{"delta_st":0,"file_extension":"sp0","channel":0'
      + ',"channel_name":"high_power","laser_wavelength":0,"sample_bits":12,"fi'
      + 'le_uuid":"da084413-e3e8-4655-a122-071de8490d8e","sample_interval":1.00'
      + '503e-09},{"delta_st":0,"file_extension":"sp1","channel":1,"channel_nam'
      + 'e":"low_power","laser_wavelength":0,"sample_bits":12,"file_uuid":"9358'
      + '5b5e-5ea9-43a1-947b-e7ba3be642d2","sample_interval":1.00503e-09},{"del'
      + 'ta_st":0,"file_extension":"sp5","channel":5,"channel_name":"wwf","lase'
      + 'r_wavelength":0,"sample_bits":12,"file_uuid":"9d2298c4-1036-464f-b5cb-'
      + '1cf8e517f3a0","sample_interval":1.00503e-09}],"sample_block_file":{"fi'
      + 'le_extension":"sbx","file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660"'
      + '},"range_offset_m":3.1415}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"array","$schema":"http://json-schema.org/draft-04/schema#","d'
      + 'escription":"Scanner settings for waveform output","items":{"type":"ob'
      + 'ject","required":["sbl_name","enabled","channel_idx_mask"],"properties'
      + '":{"enabled":{"type":"boolean","description":"Waveform output '
      + 'enabled"},"logic_expression":{"type":"string","description":"Logic '
      + 'expression of smart waveforms '
      + 'filter"},"channel_idx_mask":{"type":"integer","description":"Bit mask '
      + 'for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, ..."},"sbl_name":{"type":"string","description":"Name of sample '
      + 'block, e.g.: wfm, '
      + 'wwf"},"pass_rng_greater":{"type":"number","description":"Threshold for'
      + ' range greater than '
      + '[m]"},"pass_ampl_less":{"type":"number","description":"Threshold for '
      + 'amplitude less than '
      + '[dB]"},"smart_enabled":{"type":"boolean","description":"Smart waveform'
      + ' output enabled"},"pass_dev_greater":{"type":"integer","description":"'
      + 'Threshold for deviation greater than '
      + '[1]"},"pass_rng_less":{"type":"number","description":"Threshold for '
      + 'range less than '
      + '[m]"},"pass_ampl_greater":{"type":"number","description":"Threshold '
      + 'for amplitude greater than '
      + '[dB]"},"pass_dev_less":{"type":"integer","description":"Threshold for '
      + 'deviation less than [1]"}}},"title":"Waveform Settings"}'
    );

    Example : (''
      + '[{"enabled":true,"sbl_name":"wfm","pass_rng_greater":9.27,"pass_ampl_l'
      + 'ess":5.0,"smart_enabled":true,"channel_idx_mask":11,"pass_rng_less":13'
      + '.11,"pass_ampl_greater":1.0},{"enabled":false,"channel_idx_mask":32,"s'
      + 'bl_name":"wwf"}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["result","filter","settings"],"description":"Window '
      + 'analysis data estimated from scandata and resulting filter parameters"'
      + ',"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'properties":{"result":{"type":"object","required":["angle","range_mean'
      + '","range_sigma","amplitude_mean","amplitude_sigma","amplitude_offset"]'
      + ',"properties":{"range_mean":{"type":"array","items":{"type":"number"},'
      + '"description":"[m]"},"range_sigma":{"type":"array","items":{"type":"nu'
      + 'mber"},"description":"[m]"},"amplitude_sigma":{"type":"array","items":'
      + '{"type":"number"},"description":"[dB]"},"amplitude_offset":{"type":"ar'
      + 'ray","items":{"type":"number"},"description":"[dB]"},"timestamp":{"typ'
      + 'e":"array","items":{"type":"number"},"description":"[s]"},"amplitude_m'
      + 'ean":{"type":"array","items":{"type":"number"},"description":"[dB]"},"'
      + 'angle":{"type":"array","items":{"type":"number"},"description":"[deg]"'
      + '}}},"settings":{"type":"object","required":["range","amplitude"],"prop'
      + 'erties":{"amplitude":{"type":"object","required":["sigma_factor","addi'
      + 'tive_value"],"properties":{"sigma_factor":{"type":"number"},"additive_'
      + 'value":{"type":"number"}}},"range":{"type":"object","required":["sigma'
      + '_factor","additive_value"],"properties":{"sigma_factor":{"type":"numbe'
      + 'r"},"additive_value":{"type":"number"}}}}},"filter":{"type":"object","'
      + 'required":["angle","range_min","range_max","amplitude_max"],"propertie'
      + 's":{"angle":{"type":"array","items":{"type":"number"},"description":"['
      + 'deg]"},"range_max":{"type":"array","items":{"type":"number"},"descript'
      + 'ion":"[m]"},"amplitude_max":{"type":"array","items":{"type":"number"},'
      + '"description":"[dB]"},"range_min":{"type":"array","items":{"type":"num'
      + 'ber"},"description":"[m]"}}}},"title":"Window Analysis"}'
    );

    Example : (''
      + '{"result":{"range_mean":[0.1105621,0.1079564,0.1087088,0.1067261,0.105'
      + '4582,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.1031261],"rang'
      + 'e_sigma":[0.01869652,0.02151435,0.01747969,0.01918765,0.01945776,0.019'
      + '34862,0.01955329,0.02225589,0.02229977,0.01899122,0.02009433],"amplitu'
      + 'de_sigma":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141'
      + ',0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],"amplitude_offset"'
      + ':[1.9,1.9],"timestamp":[408.4441,411.4443],"amplitude_mean":[5.347396,'
      + '5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.00788'
      + '5,5.002441,4.982],"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.'
      + '7,15.8,15.9]},"settings":{"amplitude":{"sigma_factor":4,"additive_valu'
      + 'e":1.0},"range":{"sigma_factor":8,"additive_value":0.1}},"filter":{"an'
      + 'gle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"range_m'
      + 'ax":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.431,0.432]'
      + ',"amplitude_max":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78'
      + '],"range_min":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,'
      + '-0.223,-0.225,-0.227]}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"required":["amplitude","range","slices"],"description":"Correction '
      + 'parameters for window glass echoes","type":"object","$schema":"http://'
      + 'json-schema.org/draft-04/schema#","properties":{"slices":{"type":"arra'
      + 'y","items":{"type":"object","required":["amplitude","table"],"properti'
      + 'es":{"amplitude":{"type":"number","description":"Window echo amplitude'
      + ' of slice in '
      + 'dB"},"table":{"type":"array","minItems":1,"description":"Correction '
      + 'table (dimension defined by the ''amplitude'' and ''range'' '
      + 'objects)","items":{"type":"array","minItems":1,"description":"Table '
      + 'row (= amplitude axis)","items":{"type":"array","minItems":3,"maxItems'
      + '":3,"description":"Table column (= range '
      + 'axis)","items":{"type":"number","description":"Table cell (item 0: '
      + 'amplitude in dB, 1: range in m, 2: flags)"}}}}},"description":"Window '
      + 'echo correction parameter slice"}},"amplitude":{"type":"object","requi'
      + 'red":["minimum","maximum","entries"],"properties":{"minimum":{"type":"'
      + 'number","minimum":0.0,"description":"Minimum amplitude in '
      + 'dB"},"entries":{"type":"integer","minimum":1,"description":"Number of '
      + 'amplitude entries"},"maximum":{"type":"number","minimum":0.0,"descript'
      + 'ion":"Maximum amplitude in dB"}},"description":"Amplitude axis of '
      + 'correction table"},"range":{"type":"object","required":["minimum","max'
      + 'imum","entries"],"properties":{"minimum":{"type":"number","minimum":-2'
      + '.0,"maximum":2.0,"description":"Minimum range in '
      + 'm"},"entries":{"type":"integer","minimum":1,"description":"Number of '
      + 'range entries"},"maximum":{"type":"number","minimum":-2.0,"maximum":2.'
      + '0,"description":"Maximum range in m"}},"description":"Range axis of '
      + 'correction table"}},"title":"Window Echo Correction"}'
    );

    Example : (''
      + '{"slices":[{"amplitude":1.5,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,'
      + '1]]]},{"amplitude":2.0,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}'
      + '],"amplitude":{"minimum":2,"entries":128,"maximum":20},"range":{"minim'
      + 'um":-1.5060822940732335,"entries":128,"maximum":1.5060822940732335}}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_RECORD_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Name)));
  RDB_RIEGL_RECORD_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Title)));
  RDB_RIEGL_RECORD_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Description)));
  RDB_RIEGL_RECORD_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Schema)));
  RDB_RIEGL_RECORD_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 47); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECORD_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
